@@ -1,10 +1,10 @@
 ;;; nov.el --- Featureful EPUB reader mode
 
-;; Copyright (C) 2017-2018 Vasilij Schneidermann <mail@vasilij.de>
+;; Copyright (C) 2017-2019 Vasilij Schneidermann <mail@vasilij.de>
 
 ;; Author: Vasilij Schneidermann <mail@vasilij.de>
 ;; URL: https://github.com/wasamasa/nov.el
-;; Version: 0.2.7
+;; Version: 0.2.8
 ;; Package-Requires: ((dash "2.12.0") (esxml "0.3.3") (emacs "24.4"))
 ;; Keywords: hypermedia, multimedia, epub
 
@@ -80,7 +80,9 @@ effect in Emacs 25.1 or greater."
 (defcustom nov-render-html-function 'nov-render-html
   "Function used to render HTML.
 It's called without arguments with a buffer containing HTML and
-should change it to contain the rendered version of it.")
+should change it to contain the rendered version of it."
+  :type 'function
+  :group 'nov)
 
 (defcustom nov-pre-html-render-hook nil
   "Hook run before `nov-render-html'."
@@ -371,6 +373,7 @@ Each alist item consists of the identifier and full path."
     (define-key map (kbd "g") 'nov-render-document)
     (define-key map (kbd "v") 'nov-view-source)
     (define-key map (kbd "V") 'nov-view-content-source)
+    (define-key map (kbd "a") 'nov-reopen-as-archive)
     (define-key map (kbd "m") 'nov-display-metadata)
     (define-key map (kbd "n") 'nov-next-document)
     (define-key map (kbd "]") 'nov-next-document)
@@ -546,6 +549,12 @@ the HTML is rendered with `nov-render-html-function'."
   (interactive)
   (find-file nov-content-file))
 
+(defun nov-reopen-as-archive ()
+  "Reopen the EPUB document using `archive-mode'."
+  (interactive)
+  (with-current-buffer (find-file-literally nov-file-name)
+    (archive-mode)))
+
 (defun nov-display-metadata ()
   "View the metadata of the EPUB document in a new buffer."
   (interactive)
@@ -718,6 +727,7 @@ Saving is only done if `nov-save-place-file' is set."
     (recentf-add-file nov-file-name)))
 
 (add-hook 'nov-mode-hook 'nov-add-to-recentf)
+(add-hook 'nov-mode-hook 'hack-dir-local-variables-non-file-buffer)
 
 (provide 'nov)
 ;;; nov.el ends here
